# This file was auto-generated by Fern from our API Definition.

from ..core.api_error import ApiError
from ..types.user_refresh_error_response import UserRefreshErrorResponse


class BadRequestError(ApiError):
    def __init__(self, body: UserRefreshErrorResponse):
        super().__init__(status_code=400, body=body)
